<div dir="rtl">

# پکیج کارگزاری پلتفرم پاد

با استفاده از این پکیج می توانید کارهایی مانند ثبت کسب و کارهای همکار، اعطای مجوز فروش و ... را انجام دهید.

# نصب

برای نصب از طریق `pip` کافیه تا دستور زیر را اجرا کنید
```
pip install pod-dealing
```


# نمونه کد

نمونه کد ها و مثال هایی از تمام متدهای این پکیج را می توانید 
[اینجا](examples)
پیدا کنید.

</div>